readOnly property
Starts the editor in read-only mode. The user can see and select text but cannot edit it.
Implementation
final bool readOnly;
Starts the editor in read-only mode. The user can see and select text but cannot edit it.
final bool readOnly;