SmartEditor class

A pure Flutter rich text HTML editor widget.

SmartEditor provides a full-featured WYSIWYG editor with:

  • Rich text formatting (bold, italic, underline, strikethrough)
  • Heading styles (H1–H6)
  • Undo/redo
  • HTML input/output
  • Customizable toolbar
  • Dark mode support
final controller = SmartEditorController();

SmartEditor(
  controller: controller,
  editorSettings: SmartEditorSettings(
    hint: 'Start typing...',
  ),
)
Inheritance

Constructors

SmartEditor({Key? key, required SmartEditorController controller, SmartEditorSettings editorSettings = const SmartEditorSettings(), SmartToolbarSettings toolbarSettings = const SmartToolbarSettings()})
const

Properties

controller → SmartEditorController
The controller for this editor instance.
final
editorSettings → SmartEditorSettings
Comprehensive editor behavior, style, and event settings.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolbarSettings → SmartToolbarSettings
Toolbar appearance and behavior settings.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SmartEditor>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited