imagePickerDelegate property
Delegate function to pick an image from device files or gallery. Should return the image as a base64 Data URL or file/network URL, or null if cancelled.
Implementation
Future<String?> Function()? imagePickerDelegate;
Delegate function to pick an image from device files or gallery. Should return the image as a base64 Data URL or file/network URL, or null if cancelled.
Future<String?> Function()? imagePickerDelegate;