isInsideTable property
bool
get
isInsideTable
Whether the cursor is currently inside a table cell.
Implementation
bool get isInsideTable => focusedTableInfo != null;
Whether the cursor is currently inside a table cell.
bool get isInsideTable => focusedTableInfo != null;