searchStateNotifier property
Notifier exposing the current state of the Find & Replace overlay and matches.
Implementation
final ValueNotifier<SearchState> searchStateNotifier =
ValueNotifier<SearchState>(SearchState.empty);
Notifier exposing the current state of the Find & Replace overlay and matches.
final ValueNotifier<SearchState> searchStateNotifier =
ValueNotifier<SearchState>(SearchState.empty);