setSearchQuery method
Sets the active search query and searches the document.
Implementation
void setSearchQuery(String query) {
searchStateNotifier.value = searchState.copyWith(
query: query,
clearError: true,
);
_performSearch();
}
Sets the active search query and searches the document.
void setSearchQuery(String query) {
searchStateNotifier.value = searchState.copyWith(
query: query,
clearError: true,
);
_performSearch();
}